@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,17 +7,19 @@
 #ifndef AutoCorrectionWidget_H
 #define AutoCorrectionWidget_H
 
-#include "pimcommon_export.h"
 #include "pimcommon/autocorrection.h"
+#include "pimcommon_export.h"
 #include <QWidget>
 
 class QTreeWidgetItem;
 
-namespace Ui {
+namespace Ui
+{
 class AutoCorrectionWidget;
 }
 
-namespace PimCommon {
+namespace PimCommon
+{
 class AutoCorrectionWidgetPrivate;
 /**
  * @brief The AutoCorrectionWidget class
@@ -28,13 +30,10 @@ class PIMCOMMON_EXPORT AutoCorrectionWidget : public QWidget
     Q_OBJECT
 
 public:
-    enum ImportFileType {
-        LibreOffice,
-        KMail
-    };
+    enum ImportFileType { LibreOffice, KMail };
 
     explicit AutoCorrectionWidget(QWidget *parent = nullptr);
-    ~AutoCorrectionWidget();
+    ~AutoCorrectionWidget() override;
     void setAutoCorrection(AutoCorrection *autoCorrect);
     void loadConfig();
     void writeConfig();
