@@ -1,29 +1,23 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef KACTIONMENUCHANGECASE_H
 #define KACTIONMENUCHANGECASE_H
 
-#include <KActionMenu>
 #include "pimcommon_export.h"
+#include <KActionMenu>
 class QAction;
 class KActionCollection;
-namespace PimCommon {
+namespace PimCommon
+{
 class KActionMenuChangeCasePrivate;
+/**
+ * @brief The KActionMenuChangeCase class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class PIMCOMMON_EXPORT KActionMenuChangeCase : public KActionMenu
 {
     Q_OBJECT
