@@ -1,37 +1,28 @@
 /*
-  Copyright (C) 2008 Omat Holding B.V. <info@omat.nl>
+  SPDX-FileCopyrightText: 2008 Omat Holding B.V. <info@omat.nl>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef PIMCOMMON_COLLECTIONANNOTATIONSATTRIBUTE_H
 #define PIMCOMMON_COLLECTIONANNOTATIONSATTRIBUTE_H
 
-#include <Attribute>
 #include "pimcommonakonadi_export.h"
+#include <Attribute>
 
 #include <QMap>
 
-namespace PimCommon {
+namespace PimCommon
+{
+/**
+ * @brief The CollectionAnnotationsAttribute class
+ */
 class PIMCOMMONAKONADI_EXPORT CollectionAnnotationsAttribute : public Akonadi::Attribute
 {
 public:
     CollectionAnnotationsAttribute();
     CollectionAnnotationsAttribute(const QMap<QByteArray, QByteArray> &annotations);
-    ~CollectionAnnotationsAttribute() = default;
+    ~CollectionAnnotationsAttribute() override = default;
 
     void setAnnotations(const QMap<QByteArray, QByteArray> &annotations);
     QMap<QByteArray, QByteArray> annotations() const;
